@@ -1,5 +1,5 @@
 package Date::Manip::Base;
-# Copyright (c) 1995-2014 Sullivan Beck.  All rights reserved.
+# Copyright (c) 1995-2015 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -25,7 +25,7 @@ use Encode qw(encode_utf8 from_to find_encoding decode _utf8_off _utf8_on is_utf
 require Date::Manip::Lang::index;
 
 our $VERSION;
-$VERSION='6.47';
+$VERSION='6.50';
 END { undef $VERSION; }
 
 ###############################################################################
@@ -163,6 +163,10 @@ sub _init_config {
 
       'periodtimesep'    => 0,
 
+      # How to parse mmm#### strings
+
+      'format_mmmyyyy'   => '',
+
       # *** DEPRECATED ***
 
       'tz'               => '',
@@ -1135,6 +1139,10 @@ sub _config_var_base {
       # We have to redo the time regexp
       delete $$self{'data'}{'rx'}{'time'};
 
+   } elsif ($var eq 'format_mmmyyyy') {
+      my $err = $self->_config_var_format_mmmyyyy($val);
+      return  if ($err);
+
    } elsif ($var eq 'dateformat'    ||
             $var eq 'jan1week1'     ||
             $var eq 'printable'     ||
@@ -1330,6 +1338,18 @@ sub _config_var_defaulttime {
    return 1;
 }
 
+sub _config_var_format_mmmyyyy {
+   my($self,$val) = @_;
+
+   if (lc($val) eq 'first'  ||
+       lc($val) eq 'last'   ||
+       lc($val) eq '') {
+      return 0;
+   }
+   warn "ERROR: [config_var] invalid: Format_MMMYYYY: $val\n";
+   return 1;
+}
+
 ###############################################################################
 # Language functions
 
