@@ -1,5 +1,5 @@
 package Date::Manip::Lang::spanish;
-# Copyright (c) 1998-2014 Sullivan Beck. All rights reserved.
+# Copyright (c) 1998-2015 Sullivan Beck. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -13,7 +13,7 @@ use warnings;
 use utf8;
 
 our($VERSION);
-$VERSION='6.47';
+$VERSION='6.50';
 
 our($Language,@Encodings,$LangName,$YearAdded);
 @Encodings = qw(utf-8 iso-8859-1 perl);
@@ -37,9 +37,9 @@ $Language = {
   each => ['cada'],
   fields => [
     ['anos', 'a', 'ano', 'ano', 'anos', 'años', 'año'],
-    ['meses', 'm', 'mes', 'mes'],
-    ['semanas', 'sem', 'semana', 'semana'],
-    ['dias', 'd', 'dia'],
+    ['meses', 'm', 'mes'],
+    ['semanas', 'sem', 'semana'],
+    ['dias', 'd', 'dia', 'días'],
     ['horas', 'hr', 'hrs', 'hora'],
     ['minutos', 'min', 'min', 'minuto'],
     ['segundos', 's', 'seg', 'segundo'],
@@ -473,6 +473,7 @@ $Language = {
   offset_date => {
     ayer => '-0:0:0:1:0:0:0',
     Hoy => '0:0:0:0:0:0:0',
+    'mañana' => '+0:0:0:1:0:0:0',
     manana => '+0:0:0:1:0:0:0',
   },
   offset_time => { Ahora => '0:0:0:0:0:0:0' },
